h1 {
            margin-left: 75px;
        }
        body {
            background-color: #F0F0F0;
            font-family: "Arial";
        }

        
        .connectbar{
            width: 100%;
        }

        .connectbar div{
          border-radius : 7px;
            background-color: #ff326b;
            width: 150px;
            height: 28px;

            text-align: center;
            margin: auto;
        }
        .connectbar a{
           /* margin-left: 200px;*/
            font-size: 18px;
            font-family: 'Open Sans',sans-serif;
            font-weight: 400;
            color:#fff;
            text-decoration: none;
            

        }

        .connectbar div.connectStatus{
            background-color: transparent;
           /* width: auto;*/
        }


        .connectbar h4{
            font-size: 14px;
            font-family: 'Open Sans',sans-serif;
            font-weight: 400;
           
           /* text-align: center;*/
          /*  margin-left: 50%;
            transform: translateX(-30px);*/
            margin-top: 5px;
            margin-bottom: 5px;
         }

        .connectbar h4.inactive{
           color:#00B1E6;
        }

        .connectbar h4.active{
          color: #41C197;
        }

         .connectbar div.welcome{
            background-color: transparent;
            /* display: inline;*/
            width: 50%;
           /* height: auto;*/
            
        }

        .welcome .welcomeLine{
            display: inline;
             background-color: transparent;
        }

        .welcome .welcomeLine h2{
            font-size: 22px;
            font-family: 'Open Sans',sans-serif;
            font-weight: 400;
            color:#00B1E6;
            display: inline;
        }

        .welcome .welcomeLine h3{
           font-size: 20px;
            font-family: 'Open Sans',sans-serif;
            font-weight: bold;
            color:#ff326b;
            /*text-align: center;*/
            display: inline;
        }

        .welcome code{
            font-size: 20px;
            font-family: 'Open Sans',sans-serif;
            font-weight: bold;
            color: #ffd639;
            /*text-align: center;*/
            display: block;
        }


         

        .box {
            width: 335px;
            float: right;
            margin: 0 20px 0 20px;
            margin-top: 30px;
        }
 
        

        .boxleft{
          float: left;
        }

        .box div {
            border-color: gray;
            height: 360px;
            overflow: auto;
        }
        
        .box div.groupchatTB{
          height: auto;
  
        }
  
          .box div.groupchatTB h4{
            margin-bottom: 0px;
             font-size: 16px;
            font-family: 'Open Sans',sans-serif;
            font-weight: bold;
            color:#ff326b;
            margin-left: 80px;
            display: inline;
          }

          .boxleft div.groupchatTB h4{
             margin-left: 120px;
          }

            .box div.groupchatTB h3{
            margin-bottom: 0px;
             font-size: 15px;
            font-family: 'Open Sans',sans-serif;
            font-weight: 300;
            
          }





        .box div.groupchatCB, .box input.groupchatCB {
            
            border: 1px solid;
            -moz-border-radius: 4px;
            border-radius: 4px;
            width: 100%;
            padding: 0px;
            margin: 5px;
        }

        .boxleft div.privateList{
            overflow: scroll;
            background: #fff;
        }
  

        .boxleft div.privateList .privateUserList{
            list-style: none;
            width: 320px;
           background: #fff;

        }
      
        
        .boxleft div.privateList .privateUserList:hover{
         cursor: pointer;
          cursor: hand;
         
          
        }


        .boxleft div.privateList .privateUserList .privateUser{
            font-size: 16px;
            
            border-bottom: 2px solid #e8e8e8;
            margin-left: -50px;

        }


        


        .boxleft div.privateList .privateUserList .privateUser p{
            font-family: 'Open Sans',sans-serif;
            font-weight: 400;
            color:#666;
            font-size: 15px;
            margin-left: 50px;
        }


      .boxleft div.privateList .privateUser:hover p{
        color:#41C197;
        font-weight: bold;
      }

        
        .box input {
            height: 40px;
        }
